@@ -29,11 +29,11 @@ pub struct UserInfo {
     pub subscribe: i8,
     pub openid: String,
     pub nickname: String,
-    pub sex: i8,
-    pub city: String,
-    pub country: String,
-    pub province: String,
-    pub language: String,
+    pub sex: Option<i8>,
+    pub city: Option<String>,
+    pub country: Option<String>,
+    pub province: Option<String>,
+    pub language: Option<String>,
     pub headimgurl: String,
     pub subscribe_time: i64,
     pub unionid: Option<String>,
